smartcard.pcsc

# ``smartcard`.`pcsc``

package documentation

Undocumented

Module | `PCSCCardConnection` | PCSCCardConnection class manages connections thru a PCSC reader.
Module | `PCSCCardRequest` | PCSC Smartcard request.
Module | `PCSCContext` | PCSC context singleton.
Module | `PCSCExceptions` | Smartcard module exceptions.
Module | `PCSCPart10` | PCSCPart10: PC/SC Part 10 (pinpad)
Module | `PCSCReader` | PCSCReader: concrete reader class for PCSC Readers
Module | `PCSCReaderGroups` | PCSCReaderGroups organizes smartcard readers as groups.